@@ -1,8 +1,6 @@
 #
 # (c) Jan Gehring <jan.gehring@gmail.com>
 #
-# vim: set ts=2 sw=2 tw=0:
-# vim: set expandtab:
 
 =head1 NAME
 
@@ -24,22 +22,22 @@ To use this module inside your Rexfile you can use the following commands.
    zone => "eu-west-1a",
    authkey => "default",
  };
-  
+
  task "prepare_box", sub {
    box {
      my ($box) = @_;
-       
+
      $box->name("mybox");
      $box->ami("ami-c1aaabb5");
-     $box->type("m1.large"); 
-        
+     $box->type("m1.large");
+
      $box->security_group("default");
-        
+
      $box->auth(
        user => "root",
        password => "box",
      );
-        
+
      $box->setup("setup_task");
    };
  };
@@ -63,7 +61,7 @@ If you want to use a YAML file you can use the following template.
 And then you can use it the following way in your Rexfile.
 
  use Rex::Commands::Box init_file => "file.yml";
-   
+
  task "prepare_vms", sub {
    boxes "init";
  };
@@ -77,8 +75,7 @@ See also the Methods of Rex::Box::Base. This module inherits all methods of it.
 
 package Rex::Box::Amazon;
 
-use 5.010001;
-use strict;
+use v5.12.5;
 use warnings;
 use Data::Dumper;
 use Rex::Box::Base;
@@ -86,13 +83,13 @@ use Rex::Commands -no => [qw/auth/];
 use Rex::Commands::Fs;
 use Rex::Commands::Cloud;
 
-our $VERSION = '1.13.4'; # VERSION
+our $VERSION = '1.16.0'; # VERSION
 
 BEGIN {
   LWP::UserAgent->use;
 }
 
-use Time::HiRes qw(tv_interval gettimeofday);
+use Time::HiRes    qw(tv_interval gettimeofday);
 use File::Basename qw(basename);
 
 use base qw(Rex::Box::Base);
