@@ -13,7 +13,7 @@ With this module you can manage user and groups.
 =head1 SYNOPSIS
 
  use Rex::Commands::User;
- 
+
  task "create-user", "remoteserver", sub {
    create_user "root",
      uid         => 0,
@@ -34,11 +34,10 @@ With this module you can manage user and groups.
 
 package Rex::Commands::User;
 
-use 5.010001;
-use strict;
+use v5.12.5;
 use warnings;
 
-our $VERSION = '1.14.0'; # VERSION
+our $VERSION = '1.16.0'; # VERSION
 
 require Rex::Exporter;
 use Rex::Commands::Fs;
