@@ -4,11 +4,10 @@
 
 package Rex::Helper::File::Stat;
 
-use 5.010001;
-use strict;
+use v5.12.5;
 use warnings;
 
-our $VERSION = '1.14.0'; # VERSION
+our $VERSION = '1.16.0'; # VERSION
 
 require Rex::Helper::File::Stat::Unix;
 require Rex::Helper::File::Stat::Win32;
