@@ -4,11 +4,10 @@
 
 package Rex::Interface::Connection::Local;
 
-use 5.010001;
-use strict;
+use v5.12.5;
 use warnings;
 
-our $VERSION = '1.14.0'; # VERSION
+our $VERSION = '1.16.0'; # VERSION
 
 use Rex::Interface::Connection::Base;
 use Rex::Group::Entry::Server;
