@@ -7,11 +7,12 @@ package Rex::Interface::Exec::Local;
 use v5.12.5;
 use warnings;
 
-our $VERSION = '1.14.1'; # VERSION
+our $VERSION = '1.16.0'; # VERSION
 
 use Rex::Logger;
 use Rex::Commands;
 
+use English qw(-no_match_vars);
 use Symbol 'gensym';
 use IPC::Open3;
 use IO::Select;
@@ -38,7 +39,7 @@ sub set_env {
     if ( ref $env ne "HASH" );
 
   while ( my ( $k, $v ) = each(%$env) ) {
-    $cmd .= "export $k='$v'; ";
+    $cmd .= $OSNAME eq 'MSWin32' ? "set $k=$v && " : "export $k='$v'; ";
   }
   $self->{env} = $cmd;
 }
@@ -49,7 +50,8 @@ sub exec {
   my ( $out, $err, $pid );
 
   if ( exists $option->{cwd} ) {
-    $cmd = "cd " . $option->{cwd} . " && $cmd";
+    my $cd_cmd = $OSNAME eq 'MSWin32' ? 'cd /d' : 'cd';
+    $cmd = "$cd_cmd " . $option->{cwd} . " && $cmd";
   }
 
   if ( exists $option->{path} ) {
@@ -85,6 +87,11 @@ sub exec {
 
     $cmd = $new_cmd;
   }
+  else {
+    if ( $self->{env} ) {
+      $cmd = $self->{env} . " $cmd";
+    }
+  }
 
   Rex::Logger::debug("Executing: $cmd");
 
