@@ -1,15 +1,13 @@
 #
 # (c) Nathan Abu <aloha2004@gmail.com>
 #
-# vim: set ts=2 sw=2 tw=0:
-# vim: set expandtab:
 
 package Rex::Output::Base;
 
-use strict;
+use v5.12.5;
 use warnings;
 
-our $VERSION = '1.12.2'; # VERSION
+our $VERSION = '1.16.0'; # VERSION
 
 sub write { die "Must be implemented by inheriting class" }
 sub add   { die "Must be implemented by inheriting class" }
