@@ -1,16 +1,13 @@
 #
 # (c) Jan Gehring <jan.gehring@gmail.com>
 #
-# vim: set ts=2 sw=2 tw=0:
-# vim: set expandtab:
 
 package Rex::Virtualization::VBox::forward_port;
 
-use 5.010001;
-use strict;
+use v5.12.5;
 use warnings;
 
-our $VERSION = '1.13.4'; # VERSION
+our $VERSION = '1.16.0'; # VERSION
 
 use Rex::Logger;
 use Rex::Helper::Run;
@@ -69,4 +66,3 @@ sub execute {
 }
 
 1;
-
